################################################################################
#
# Copyright (c) 2020 Baidu.com, Inc. All Rights Reserved
#
################################################################################

"""
This module provides methods to interact with the console
"""
import copy
import json
import logging
import sys

from baidubce import bce_base_client
from baidubce.auth import bce_v1_signer
from baidubce.http import bce_http_client
from baidubce.http import handler
from baidubce.http import http_methods
from baidubce import migration_request
from baidubce import utils

LOG_FORMAT = "%(asctime)s - %(levelname)s - %(message)s"
DATE_FORMAT = "%m/%d/%Y %H:%M:%S %p"
logging.basicConfig(level=logging.INFO, format=LOG_FORMAT, datefmt=DATE_FORMAT)


class AgentClient(bce_base_client.BceBaseClient):
    """
    Agent http client
    """
    def __init__(self, config=None):
        bce_base_client.BceBaseClient.__init__(self, config)

    def _merge_config(self, config=None):
        if config is None:
            return self.config
        else:
            new_config = copy.copy(self.config)
            new_config.merge_non_none_values(config)
            return new_config

    def _send_request(self, http_method, path,
                      body=None, headers=None,
                      params=None, config=None, body_parser=None):
        config = self._merge_config(config)
        if body_parser is None:
            body_parser = handler.parse_json

        return bce_http_client.send_request(
            config, bce_v1_signer.sign, [handler.parse_error, body_parser],
            http_method, path, body, headers, params)

    def heart_beat(self, heart_beat_request):
        """
        Send heart beat to console

        :param migration_source_id: the id of migration source
        :type migration_source_id: string

        :param task_info: task execution information
        :type task_info: dict

        :return
        :rtype baidubce.bce_response.BceResponse
        """
        path = b'/api/logic/mc/v1/task/heartSynchronize'
        body = heart_beat_request
        return self._send_request(http_method=http_methods.POST, path=path,
                                  body=json.dumps(body, default=utils.ComplexHandler))

    def register_migration_source(self):
        """
        Register migration source information

        :return
        :rtype baidubce.bce_response.BceResponse
        """
        path = b'/api/logic/mc/v1/source/create'

        body = migration_request.MigrationRequest()
        logging.debug("migration request body: %s", body)
        try:
            return self._send_request(http_method=http_methods.POST, path=path,
                                      body=json.dumps(body, default=utils.ComplexHandler))
        except Exception as e:
            logging.error("Register migration source error: %s", e)
            sys.exit(1)

