################################################################################
#
# Copyright (c) 2020 Baidu.com, Inc. All Rights Reserved
#
################################################################################

"""
This module represents the data sent when sending heart beat to console
"""

class SubTask(object):
    """
    The information of subtask
    """
    def __init__(self, name):
        self.name = name
        self.start_time = ""
        self.end_time = ""
        self.progress = 0

    def set_start_time(self, start_time):
        """
        Set the start time of subtask
        """
        self.start_time = start_time

    def set_end_time(self, end_time):
        """
        Set the end time of subtask
        """
        self.end_time = end_time

    def set_progress(self, progress):
        """
        Set the progress of subtask
        """
        self.progress = progress

    def jsonable(self):
        """
        Return the json representation of the object
        """
        return self.__dict__


class TaskInfo(object):
    """
    The information of the task
    """
    def __init__(self):
        self.finished = False
        self.status = ""
        self.speed = ""
        self.left_time = ""
        self.progress = ""
        self.err_log = ""
        self.sub_task = []

    def set_status(self, status):
        """
        Set the status of the task
        """
        self.status = status

    def set_finished(self, finished):
        """
        Flag whether the task is finished
        """
        self.finished = finished

    def set_speed_left_time_progress(self, speed, left_time, progress):
        """
        Set the speed, left time, progress of the task
        """
        self.speed = speed
        self.left_time = left_time
        self.progress = progress

    def set_err_log(self, err_log):
        """
        Set the error log of the task
        """
        self.err_log = err_log

    def add_sub_task(self, sub_task):
        """
        Add subtask information
        """
        self.sub_task.append(sub_task)

    def jsonable(self):
        """
        Return the json representation of the object
        """
        return self.__dict__


class HeartBeatRequest(object):
    """
    The heart beat request
    """
    def __init__(self, migration_source_id):
        self.migration_source_id = migration_source_id
        self.task_info = TaskInfo()

    def jsonable(self):
        """
        Return the json representation of the object
        """
        return self.__dict__



