################################################################################
#
# Copyright (c) 2020 Baidu.com, Inc. All Rights Reserved
#
################################################################################
"""
This module provides heartbeat related classes
"""
import logging


class HeartBeatParams(object):
    """
    Heart beat parameter class
    """
    def __init__(self, migration_source_id, task_info=None):
        self.migration_source_id = migration_source_id
        self.task_info = task_info

    def set_task_info(self, task_info):
        """
        Set task information

        :param task_info: Task execution information
        :type task_info: dict

        :return
        :rtype None
        """
        self.task_info = task_info

    def get_migration_source_id_task_info(self):
        """
        Get migration source id and task execution information

        :return
        :rtype string, dict
        """
        return self.migration_source_id, self.task_info


class TaskMetadata(object):
    """
    The metadata of the task.
    """
    def __init__(self):
        self.id = ""
        self.started = False
        self.error = False
        self.bwlimit = 0
        self.dest_ip = ""
        self.dest_root_user = ""
        self.disk_to_trans = []


class HeartBeatResponse(object):
    """
    Heart beat response class
    """
    def __init__(self):
        self.task_metadata = TaskMetadata()

    def set_task_metadata(self, task_metadata):
        """
        Set task metadata

        :param task_metadata: The metadata of task
        :type task_metadata: TaskMetadata

        :return
        :rtype None
        """
        self.task_metadata.id = task_metadata.id
        self.task_metadata.started = task_metadata.started
        self.task_metadata.error = task_metadata.error
        self.task_metadata.bwlimit = task_metadata.bwlimit
        self.task_metadata.dest_ip = task_metadata.dest_ip
        self.task_metadata.dest_root_user = task_metadata.dest_root_user
        self.task_metadata.disk_to_trans = task_metadata.disk_to_trans

    def get_task_metadata(self):
        """
        Get task metadata

        :return
        :rtype dict
        """
        return self.task_metadata


class HeartBeat(object):
    """
    Heart beat class
    """
    def __init__(self, heart_beat_request, heart_beat_response, agent_client):
        self.heart_beat_request = heart_beat_request
        self.heart_beat_response = heart_beat_response
        self.agent_client = agent_client

    def heart_beat(self):
        """
        Send heartbeat packet to console
        """
        bce_response = self.agent_client.heart_beat(self.heart_beat_request)
        if hasattr(bce_response, 'task_metadata'):
            logging.info("heart beat task meta: %s", bce_response.task_metadata)
            self.heart_beat_response.set_task_metadata(bce_response.task_metadata)
