################################################################################
#
# Copyright (c) 2020 Baidu.com, Inc. All Rights Reserved
#
################################################################################
"""
This module provides methods for replacing the old UUID to the new UUID.
"""

from migrate_center_agent import utils
import migrate_center_agent
import shlex
import subprocess

class Modify(object):
    """
    Replacing the old UUID to the new UUID.
    """
    def __init__(self, root_user, ip):
        self.root_user = root_user
        self.ip = ip
        self.err = False
        self.err_log = None
        self.finished = False

    def get_new_uuid(self):
        """
        Get the uuid of the remote system disk
        """
        remote_system_disk = utils.get_system_disk_from_mount_dir(self.root_user, self.ip)
        cmd = utils.ssh_command_prefix(self.root_user, self.ip) + "\"blkid\""
        cmd = shlex.split(cmd)
        process = subprocess.Popen(cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE, universal_newlines=True)
        process.wait()
        logs = process.stdout.readlines()
        uuid = ""
        for log in logs:
            if remote_system_disk in log:
                uuid = log.split()[1].split("=")[-1].strip("\"")
                break
        return uuid

    def get_old_uuid(self):
        """
        Get the local system disk uuid
        """
        grub_cfg_path = utils.get_grub_cfg_path()
        cmd = utils.ssh_command_prefix(self.root_user, self.ip) + "\"cat {}\"".format(grub_cfg_path)
        cmd = shlex.split(cmd)
        process = subprocess.Popen(cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE, universal_newlines=True)
        process.wait()
        logs = process.stdout.readlines()
        uuid = ""
        for log in logs:
            if "UUID" in log:
                uuid = log.split()[2].split("=")[-1]
        return uuid

    def replace_uuid(self):
        """
        Replace old uuid to new uuid
        """
        new_uuid = self.get_new_uuid()
        old_uuid = self.get_old_uuid()
        grub_cfg_path = utils.get_grub_cfg_path()
        fstab_path = migrate_center_agent.SYSTEM_DISK_MOUNT_DIR + "/etc/fstab"
        paths = [grub_cfg_path, fstab_path]
        for path in paths:
            cmd = utils.ssh_command_prefix(self.root_user, self.ip) + \
                  "\"sed -ri s/{}/{}/g {}\"".format(old_uuid, new_uuid, path)
            cmd = shlex.split(cmd)
            process = subprocess.Popen(cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE, universal_newlines=True)
            process.wait()
            self.err, self.err_log = utils.error_handler(process)
            if self.err:
                return
        self.finished = True
