################################################################################
#
# Copyright (c) 2020 Baidu.com, Inc. All Rights Reserved
#
################################################################################
"""
This module provides rsync related tools
"""
from migrate_center_agent import rsync

import os
import logging
import getpass


LOG_FORMAT = "%(asctime)s - %(levelname)s - %(message)s"
DATE_FORMAT = "%m/%d/%Y %H:%M:%S %p"
logging.basicConfig(level=logging.WARNING, format=LOG_FORMAT, datefmt=DATE_FORMAT)

def get_default_exclude_paths():
    """
    Get the default excluded paths of system disk

    :return
    :rtype list
    """
    path = rsync.DEFAULT_EXCLUDE_CFG_PATH
    if os.path.exists(path):
        f = open(path, 'r')
        default_exclude_paths = f.readlines()
        f.close()
        return default_exclude_paths
    else:
        logging.warning("The config file: %s, which used to specify which paths are excluded, does not exist, so "
                        "all files on system disk will be synced.", path)
        return []


def get_custom_exclude_paths():
    """
    Get the custom excluded paths

    :return
    :rtype list
    """
    path = rsync.CUSTOM_EXCLUDE_CFG_PATH
    if os.path.exists(path):
        f = open(path, 'r')
        custom_exclude_paths = f.readlines()
        f.close()
        return custom_exclude_paths
    else:
        return []


def get_exclude_paths_from_cfg_files():
    """
    Get all exclude paths

    :return
    :rtype list
    """
    return get_custom_exclude_paths()


def get_user():
    """
    Get current user name

    :return
    :rtype string
    """
    return getpass.getuser()
