################################################################################
#
# Copyright (c) 2020 Baidu.com, Inc. All Rights Reserved
#
################################################################################
"""
This module provides methods for umounting filesystem and disk.
"""
from migrate_center_agent import utils
import migrate_center_agent

import subprocess
import shlex

class Umount(object):
    """
    Umount file system and system disk.
    """
    def __init__(self, root_user, ip):
        self.root_user = root_user
        self.ip = ip
        self.err = False
        self.err_log = None
        self.finished = False

    def execute_remote_command(self, command):
        """
        Execute command on remote server.
        """
        cmd = utils.ssh_command_prefix(self.root_user, self.ip) + "\"" + command + "\""
        cmd = shlex.split(cmd)
        process = subprocess.Popen(cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE, universal_newlines=True)
        process.wait()
        err, err_log = utils.error_handler(process)
        return err, err_log

    def umount_proc(self):
        """
        Umount proc file system
        """
        command = "umount {}/proc/".format(migrate_center_agent.SYSTEM_DISK_MOUNT_DIR)
        return self.execute_remote_command(command)

    def umount_bind(self):
        """
        Umount bind file system
        """
        command = "umount {}/dev/".format(migrate_center_agent.SYSTEM_DISK_MOUNT_DIR)
        err, err_log = self.execute_remote_command(command)
        if err:
            return err, err_log
        command = "umount {}/sys/".format(migrate_center_agent.SYSTEM_DISK_MOUNT_DIR)
        return self.execute_remote_command(command)

    def umount_devpts(self):
        """
        Umount devpts file system
        """
        command = "umount {}/dev/pts".format(migrate_center_agent.SYSTEM_DISK_MOUNT_DIR)
        return self.execute_remote_command(command)

    def umount_system_disk(self):
        """
        Umount the system disk
        """
        system_disk = utils.get_system_disk_from_mount_dir(self.root_user, self.ip)
        command = "umount {}".format(system_disk)
        return self.execute_remote_command(command)

    def umount(self):
        """
        Umount file system and system disk.
        """
        self.err, self.err_log = self.umount_devpts()
        if self.err:
            return
        self.err, self.err_log = self.umount_bind()
        if self.err:
            return
        self.err, self.err_log = self.umount_proc()
        if self.err:
            return
        self.err, self.err_log = self.umount_system_disk()
        self.finished = True



