from baidubce import agent_client
from baidubce.auth.bce_credentials import BceCredentials
from baidubce.bce_client_configuration import BceClientConfiguration
from baidubce import heartbeat_request

import unittest

class TestAgentClient(unittest.TestCase):
    def setUp(self) -> None:
        """
        Set up agent client
        """
        host = b"http://localhost:8080"
        ak = b"test"
        sk = b"test"
        config = BceClientConfiguration(credentials=BceCredentials(ak, sk),
                                        endpoint=host)
        self.client = agent_client.AgentClient(config)

    def test_register_migration_source(self):
        """
        Test the http interface of registering migration source
        """
        response = self.client.register_migration_source()
        print(response)
        self.assertTrue(response.success)

    def test_heart_beat(self):
        """
        Test the http interface of heart beat
        """
        migration_source_id = "test"
        heart_beat_request = heartbeat_request.HeartBeatRequest(migration_source_id=migration_source_id)
        response = self.client.heart_beat(heart_beat_request)
        print(response)
        self.assertTrue(response.task_metadata is not None)

if __name__ == '__main__':
    suite = unittest.TestSuite()
    suite.addTest(TestAgentClient("test_register_migration_source"))
    suite.addTest(TestAgentClient("test_heart_beat"))
    runner = unittest.TextTestRunner()
    runner.run(suite)
