from migrate_center_agent import run
from migrate_center_agent import heart_beat
from migrate_center_agent import task_status
from baidubce import agent_client
from baidubce import heartbeat_request
from baidubce.auth.bce_credentials import BceCredentials
from baidubce.bce_client_configuration import BceClientConfiguration

import unittest
import gevent


class TestRun(unittest.TestCase):
    def setUp(self) -> None:
        """
        Set up agent client
        """
        host = b"http://localhost:8080"
        ak = b"test"
        sk = b"test"
        self.run_instance = run.Run()
        config = BceClientConfiguration(credentials=BceCredentials(ak, sk),
                                        endpoint=host)
        self.run_instance.client = agent_client.AgentClient(config)
        self.run_instance.migration_source_id = self.run_instance.register_migration_source(self.run_instance.client)
        self.run_instance.heart_beat_request = heartbeat_request.HeartBeatRequest(
            migration_source_id=self.run_instance.migration_source_id
        )
        self.run_instance.heart_beat_response = heart_beat.HeartBeatResponse()
        self.hb = heart_beat.HeartBeat(heart_beat_request=self.run_instance.heart_beat_request,
                                       heart_beat_response=self.run_instance.heart_beat_response,
                                       agent_client=self.run_instance.client)


    def test_register_migration_source(self):
        """
        Test register migration source
        """
        print(self.run_instance.migration_source_id)
        self.assertTrue(self.run_instance.migration_source_id is not None)

    def test_start_heart_beat(self):
        """
        Test heart beat
        """
        gevent.spawn(self.run_instance.start_heart_beat, self.hb)
        gevent.sleep(5)
        task_metadata = self.run_instance.heart_beat_response.task_metadata
        self.run_instance.terminated = True
        gevent.sleep(5)
        print(task_metadata.started)
        self.assertTrue(task_metadata.id is not None)

    def test_run(self):
        """
        Test sync files and send task information to console
        """
        gevent.spawn(self.run_instance.start_heart_beat, self.hb)
        while not self.run_instance.terminated:
            task_metadata = self.run_instance.heart_beat_response.get_task_metadata()
            if not task_metadata.error:
                if task_metadata.started:
                    self.run_instance.heart_beat_request.task_info.status = task_status.Syncing
                    if self.run_instance.mount is None:
                        self.run_instance.mount_disks()
                        self.assertFalse(self.run_instance.mount.err)
                    if self.run_instance.mount is not None and self.run_instance.mount.finished:
                        self.run_instance.sync()
                        self.assertFalse(self.run_instance.rsync.err)
                    if self.run_instance.sync_finished:
                        self.run_instance.boot_disks()
                        self.assertFalse(self.run_instance.boot.err)
                    if self.run_instance.boot is not None and self.run_instance.boot.finished:
                        self.run_instance.modify_uuid()
                        self.assertFalse(self.run_instance.modify.err)
                    if self.run_instance.modify is not None and self.run_instance.modify.finished:
                        self.run_instance.umount_disks()
                        self.assertFalse(self.run_instance.umount.err)

            gevent.sleep(1)


if __name__ == '__main__':
    suite = unittest.TestSuite()
    suite.addTest(TestRun("test_register_migration_source"))
    suite.addTest(TestRun("test_start_heart_beat"))
    suite.addTest(TestRun("test_run"))
    runner = unittest.TextTestRunner()
    runner.run(suite)
