#!/bin/sh

# print usage
function usage()
{
    echo "Usage: sh update_client.sh
-i rebuild initrd image
-h print help message
"
    exit
}

# update fstab with uuid of /dev/vdb1
function update_fstab()
{
    echo "UUID=${disk_uuid} / ext4 defaults 1 1" > ${target_root}/etc/fstab
}

# mount proc,sys,dev for target sys
function mount_target_sys()
{
    mount --bind /proc ${target_root}/proc
    mount --bind /sys ${target_root}/sys
    mount --bind /dev ${target_root}/dev
    mount -t devpts devpts ${target_root}/dev/pts
}

# umount proc,sys,dev for target sys
function umount_target_sys()
{
    umount ${target_root}/dev/pts
    umount ${target_root}/proc
    umount ${target_root}/sys
    umount ${target_root}/dev
}

# chroot into target environment
function chroot_target_env()
{
    mount_target_sys
    chroot ${target_root} $*
    umount_target_sys
}

# install grub for target
function install_grub()
{
    chroot_target_env /bin/bash -x /install_target_grub.sh ${target_disk} ${target_partition} ${disk_uuid}
}

function update_initrd()
{
    local ker_ver=$1
    if [ "${OS_TYPE}" = "Debian" ] || [ "${OS_TYPE}" = "Ubuntu" ]; then
        echo -e 'xen-blkfront\nvirtio_blk\nvirtio_pci\nvirtio_console' >> ${target_root}/etc/initramfs-tools/modules
        chroot_target_env /bin/bash mkinitramfs -o /boot/initrd.img-${ker_ver} ${ker_ver}
    elif [ "${OS_TYPE}" = "CentOS" ]; then
        mkinitrd_option=" --with=xen-blkfront --preload=xen-blkfront --with=virtio_blk --preload=virtio_blk --with=virtio_pci --preload=virtio_pci --with=virtio_console --preload=virtio_console"
        chroot_target_env /bin/bash mkinitrd -f --allow-missing ${mkinitrd_option} /boot/initramfs-${ker_ver}.img ${ker_ver}
    else
        echo "${OS_TYPE} is not supproted. Please check."
        exit 1
    fi
}
# main
#parse arguments
while getopts "t:ih" opt
do
    case $opt in
        t)      OS_TYPE=$OPTARG ;;
        i)      REBUILD_INITRD="TRUE" ;;
        h)      usage ;;
    esac
done

if [ -z "${OS_TYPE}" ]; then
    echo "Please specify the os type of source server."
    exit 1
fi

export PATH=$PATH:/sbin:/bin
# /dev/vdb mount
mount_point=/mnt/sysdisk
target_root=${mount_point}
#target_disk=vdb
target_partition=$(mount | grep "${mount_point}" | awk '{print $1}')
# vdb1 uuid
disk_uuid=$(blkid -s UUID ${target_partition} | awk '{print $2}'| sed 's/UUID=//g' | tr -d '"')
for d in $(fdisk -l  | grep  "^Disk /dev/"  | awk '{print $2}'  | tr -d ":")
do
    echo $target_partition | grep -q "$d"
    if [ $? -eq 0 ]; then
        target_disk=$d
        break
    fi
done

update_fstab
install_grub
if [ "${REBUILD_INITRD}" = "TRUE" ]; then
    for k in $(ls ${target_root}/lib/modules)
    do
        update_initrd $k
    done
fi
